@@ -26,8 +26,8 @@
 #include <QTransform>
 
 #include "latlon.h"
-#include "../core/map_coord.h"
-#include "../file_format.h"
+#include "map_coord.h"
+#include "../fileformats/file_format.h"
 
 class QDebug;
 class QXmlStreamReader;
