@@ -37,8 +37,8 @@
 
 #include "home_screen_widget.h"
 #include "../main_window.h"
-#include "../../util_gui.h"
-#include "../../util_translation.h"
+#include "gui/util_gui.h"
+#include "util/translation_util.h"
 #include "../../util/backports.h"
 #include "../../util/encoding.h"
 #include "../../util/scoped_signals_blocker.h"
@@ -188,7 +188,7 @@ void GeneralSettingsPage::apply()
 		
 		setSetting(Settings::General_Language, translation.code());
 		setSetting(Settings::General_TranslationFile, translation_file);
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_MACOS)
 		// The native [file] dialogs will use the first element of the
 		// AppleLanguages array in the application's .plist file -
 		// and this file is also the one used by QSettings.
