@@ -38,17 +38,17 @@
 #include "segmented_button_layout.h"
 #include "../main_window.h"
 #include "../../core/georeferencing.h"
-#include "../../map.h"
-#include "../../map_editor.h"
-#include "../../map_widget.h"
-#include "../../object.h"
+#include "core/map.h"
+#include "gui/map/map_editor.h"
+#include "gui/map/map_widget.h"
+#include "core/objects/object.h"
 #include "../../settings.h"
-#include "../../template.h"
-#include "../../template_adjust.h"
-#include "../../template_map.h"
-#include "../../template_position_dock_widget.h"
-#include "../../template_tool_move.h"
-#include "../../util.h"
+#include "../../templates/template.h"
+#include "../../templates/template_adjust.h"
+#include "../../templates/template_map.h"
+#include "../../templates/template_position_dock_widget.h"
+#include "../../templates/template_tool_move.h"
+#include "util/util.h"
 #include "../../util/item_delegates.h"
 #include "../../util/scoped_signals_blocker.h"
 
