@@ -1,6 +1,6 @@
 /*
  *    Copyright 2012, 2013 Thomas Schöps
- *    Copyright 2012-2016 Kai Pastor
+ *    Copyright 2012-2017 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -39,13 +39,15 @@
 #endif
 
 #include "global.h"
+#include "mapper_resource.h"
+#include "settings.h"
 #include "gui/home_screen_controller.h"
 #include "gui/main_window.h"
 #include "gui/widgets/mapper_proxystyle.h"
-#include "settings.h"
-#include "util_translation.h"
 #include "util/backports.h"
 #include "util/recording_translator.h"
+#include "util/translation_util.h"
+
 
 int main(int argc, char** argv)
 {
@@ -63,11 +65,7 @@ int main(int argc, char** argv)
 #endif
 	
 	// Load resources
-#ifdef MAPPER_USE_QT_CONF_QRC
-	Q_INIT_RESOURCE(qt);
-#endif
 	Q_INIT_RESOURCE(resources);
-	Q_INIT_RESOURCE(licensing);
 	
 	// QSettings on OS X benefits from using an internet domain here.
 	QCoreApplication::setOrganizationName(QString::fromLatin1("OpenOrienteering.org"));
@@ -83,13 +81,15 @@ int main(int argc, char** argv)
 	qapp.addLibraryPath(QCoreApplication::applicationDirPath() + QLatin1String("/plugins"));
 #endif
 	
+	MapperResource::setSeachPaths();
+	
 	// Localization
 	TranslationUtil::setBaseName(QLatin1String("OpenOrienteering"));
 	auto language = settings.getSetting(Settings::General_Language).toString();
 	auto translation_file = settings.getSetting(Settings::General_TranslationFile).toString();
 	TranslationUtil translation(language, translation_file);
 	QLocale::setDefault(QLocale(translation.code()));
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_MACOS)
 	// Normally this is done in Settings::apply() because it is too late here.
 	// But Mapper 0.6.2/0.6.3 accidently wrote a string instead of a list. This
 	// error caused crashes when opening native dialogs (i.e. the open-file dialog!).
@@ -155,11 +155,3 @@ int main(int argc, char** argv)
 	first_window.raise();
 	return qapp.exec();
 }
-
-#ifdef _MSC_VER
-#include "Windows.h"
-int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
-{
-	return main(__argc, __argv);
-}
-#endif
