@@ -1,5 +1,5 @@
 /*
- *    Copyright 2012-2016 Kai Pastor
+ *    Copyright 2012-2017 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -28,4 +28,17 @@
 #  include "qoverload.h"
 #endif
 
+#if defined(Q_OS_ANDROID) && defined(_GLIBCXX_CMATH)
+namespace std
+{
+
+template <class T>
+T hypot(T t1, T t2)
+{
+	return ::hypot(t1, t2);
+}
+
+}
+#endif
+
 #endif
