@@ -1,5 +1,5 @@
 /*
- *    Copyright 2013-2016 Kai Pastor
+ *    Copyright 2013-2017 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -24,9 +24,20 @@
 #include <QTextCodec>
 #include <QTextStream>
 
-#include "../core/map_coord.h"
-#include "../file_format_xml.h"
-#include "../file_import_export.h"
+#include "core/map_coord.h"
+#include "fileformats/file_import_export.h"
+#include "fileformats/xml_file_format.h"
+
+
+void writeLineBreak(QXmlStreamWriter& xml)
+{
+	if (!xml.autoFormatting())
+	{
+		static const QString linebreak = QLatin1String{"\n"};
+		xml.writeCharacters(linebreak);
+	}
+}
+
 
 
 //### XmlRecoveryHelper ###
