@@ -1,5 +1,5 @@
 /*
- *    Copyright 2013-2015 Kai Pastor
+ *    Copyright 2013-2017 Kai Pastor
  *
  *    This file is part of OpenOrienteering.
  *
@@ -19,16 +19,19 @@
 
 #include "map_t.h"
 
-#include "../src/map.h"
-#include "../src/core/map_color.h"
-#include "../src/core/map_printer.h"
-#include "../src/core/map_view.h"
+#include <QMessageBox>
+
+#include "core/map.h"
+#include "core/map_color.h"
+#include "core/map_printer.h"
+#include "core/map_view.h"
 
 namespace
 {
 	static QDir examples_dir;
 }
 
+
 void MapTest::initTestCase()
 {
 	Q_INIT_RESOURCE(resources);
@@ -36,8 +39,16 @@ void MapTest::initTestCase()
 	examples_dir.cd(QFileInfo(QString::fromUtf8(__FILE__)).dir().absoluteFilePath(QString::fromLatin1("../examples")));
 	// Static map initializations
 	Map map;
+	
+	// Accept any message boxes
+	connect(qApp, &QApplication::focusChanged, [](QWidget*, QWidget* w) {
+		if (w && qobject_cast<QMessageBox*>(w->window()))
+			QTimer::singleShot(0, w->window(), SLOT(accept()));
+	});
 }
 
+
+
 void MapTest::printerConfigTest()
 {
 	Map map;
@@ -50,46 +61,46 @@ void MapTest::printerConfigTest()
 
 void MapTest::specialColorsTest()
 {
-	QVERIFY(Map::getCoveringRed() != NULL);
+	QVERIFY(Map::getCoveringRed() != nullptr);
 	QCOMPARE(Map::getCoveringWhite()->getPriority(), static_cast<int>(MapColor::CoveringWhite));
 	
-	QVERIFY(Map::getCoveringWhite() != NULL);
+	QVERIFY(Map::getCoveringWhite() != nullptr);
 	QCOMPARE(Map::getCoveringRed()->getPriority(), static_cast<int>(MapColor::CoveringRed));
 	
-	QVERIFY(Map::getUndefinedColor() != NULL);
+	QVERIFY(Map::getUndefinedColor() != nullptr);
 	QCOMPARE(Map::getUndefinedColor()->getPriority(), static_cast<int>(MapColor::Undefined));
 	
-	QVERIFY(Map::getRegistrationColor() != NULL);
+	QVERIFY(Map::getRegistrationColor() != nullptr);
 	QCOMPARE(Map::getRegistrationColor()->getPriority(), static_cast<int>(MapColor::Registration));
 	
 	Map map;               // non-const
 	const Map& cmap(map);  // const
-	QCOMPARE(map.getMapColor(MapColor::CoveringWhite), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(MapColor::CoveringWhite), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(MapColor::CoveringWhite), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(MapColor::CoveringWhite), static_cast<MapColor*>(nullptr));
 	QCOMPARE(map.getColor(MapColor::CoveringWhite), Map::getCoveringWhite());
 	QCOMPARE(cmap.getColor(MapColor::CoveringWhite), Map::getCoveringWhite());
-	QCOMPARE(map.getMapColor(MapColor::CoveringRed), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(MapColor::CoveringRed), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(MapColor::CoveringRed), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(MapColor::CoveringRed), static_cast<MapColor*>(nullptr));
 	QCOMPARE(map.getColor(MapColor::CoveringRed), Map::getCoveringRed());
 	QCOMPARE(cmap.getColor(MapColor::CoveringRed), Map::getCoveringRed());
-	QCOMPARE(map.getMapColor(MapColor::Undefined), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(MapColor::Undefined), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(MapColor::Undefined), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(MapColor::Undefined), static_cast<MapColor*>(nullptr));
 	QCOMPARE(map.getColor(MapColor::Undefined), Map::getUndefinedColor());
 	QCOMPARE(cmap.getColor(MapColor::Undefined), Map::getUndefinedColor());
-	QCOMPARE(map.getMapColor(MapColor::Registration), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(MapColor::Registration), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(MapColor::Registration), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(MapColor::Registration), static_cast<MapColor*>(nullptr));
 	QCOMPARE(map.getColor(MapColor::Registration), Map::getRegistrationColor());
 	QCOMPARE(cmap.getColor(MapColor::Registration), Map::getRegistrationColor());
 	
-	QCOMPARE(map.getMapColor(MapColor::Reserved), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(MapColor::Reserved), (MapColor*)NULL);
-	QCOMPARE(map.getColor(MapColor::Reserved), (MapColor*)NULL);
-	QCOMPARE(cmap.getColor(MapColor::Reserved), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(MapColor::Reserved), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(MapColor::Reserved), static_cast<MapColor*>(nullptr));
+	QCOMPARE(map.getColor(MapColor::Reserved), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getColor(MapColor::Reserved), static_cast<MapColor*>(nullptr));
 	
-	QCOMPARE(map.getMapColor(map.getNumColors()), (MapColor*)NULL);
-	QCOMPARE(cmap.getMapColor(cmap.getNumColors()), (MapColor*)NULL);
-	QCOMPARE(map.getColor(map.getNumColors()), (MapColor*)NULL);
-	QCOMPARE(cmap.getColor(cmap.getNumColors()), (MapColor*)NULL);
+	QCOMPARE(map.getMapColor(map.getNumColors()), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getMapColor(cmap.getNumColors()), static_cast<MapColor*>(nullptr));
+	QCOMPARE(map.getColor(map.getNumColors()), static_cast<MapColor*>(nullptr));
+	QCOMPARE(cmap.getColor(cmap.getNumColors()), static_cast<MapColor*>(nullptr));
 }
 
 void MapTest::importTest_data()
@@ -114,15 +125,10 @@ void MapTest::importTest()
 	
 	auto original_size = map.getNumObjects();
 	auto original_num_colors = map.getNumColors();
-#if IMPORT_MAP_DOES_NOT_USE_GUI
 	Map empty_map;
 	map.importMap(&empty_map, Map::CompleteImport);
 	QCOMPARE(map.getNumObjects(), original_size);
 	QCOMPARE(map.getNumColors(), original_num_colors);
-#else
-	map.color_set->importSet(*map.color_set, {});
-	QCOMPARE(map.getNumColors(), original_num_colors);
-#endif
 	
 	map.importMap(&map, Map::ColorImport);
 	QCOMPARE(map.getNumObjects(), original_size);
@@ -135,20 +141,28 @@ void MapTest::importTest()
 	QString imported_path = examples_dir.absoluteFilePath(imported_file);
 	Map imported_map;
 	QVERIFY(imported_map.loadFrom(imported_path, nullptr, nullptr, false, false));
+	QVERIFY(imported_map.getNumSymbols() > 0);
 	
 	original_size = map.getNumObjects();
-	imported_map.changeScale(map.getScaleDenominator(), {}, true, true, true, true);
-	map.importMap(&imported_map, Map::CompleteImport);
+	QHash<const Symbol*, Symbol*> symbol_map;
+	map.importMap(&imported_map, Map::CompleteImport, nullptr, nullptr, -1, false, &symbol_map);
 	QCOMPARE(map.getNumObjects(), original_size + imported_map.getNumObjects());
+	QCOMPARE(symbol_map.size(), imported_map.getNumSymbols());
 }
 
+
+
 /*
- * We select a non-standard QPA because we don't need a real GUI window.
+ * We don't need a real GUI window.
  * 
- * Normally, the "offscreen" plugin would be the correct one.
- * However, it bails out with a QFontDatabase error (cf. QTBUG-33674)
+ * But we discovered QTBUG-58768 macOS: Crash when using QPrinter
+ * while running with "minimal" platform plugin.
  */
-auto qpa_selected = qputenv("QT_QPA_PLATFORM", "minimal");
+#ifndef Q_OS_MACOS
+namespace  {
+	auto qpa_selected = qputenv("QT_QPA_PLATFORM", "minimal");
+}
+#endif
 
 
 QTEST_MAIN(MapTest)
